package com.ruoyi.mall.service;

import java.util.List;
import java.util.Map;

import com.ruoyi.mall.domain.MallCareerSalary;

/**
 * 职业薪资Service接口
 *
 * @author LCL
 * @date 2023-10-19
 */
public interface IMallCareerSalaryService
{
    /**
     * 查询职业薪资
     *
     * @param careerSalaryId 职业薪资主键
     * @return 职业薪资
     */
    public MallCareerSalary selectMallCareerSalaryByCareerSalaryId(Long careerSalaryId);

    /**
     * 查询职业薪资列表
     *
     * @param mallCareerSalary 职业薪资
     * @return 职业薪资集合
     */
    public List<MallCareerSalary> selectMallCareerSalaryList(MallCareerSalary mallCareerSalary);

    /**
     * 新增职业薪资
     *
     * @param mallCareerSalary 职业薪资
     * @return 结果
     */
    public int insertMallCareerSalary(MallCareerSalary mallCareerSalary);

    /**
     * 修改职业薪资
     *
     * @param mallCareerSalary 职业薪资
     * @return 结果
     */
    public int updateMallCareerSalary(MallCareerSalary mallCareerSalary);

    /**
     * 批量删除职业薪资
     *
     * @param careerSalaryIds 需要删除的职业薪资主键集合
     * @return 结果
     */
    public int deleteMallCareerSalaryByCareerSalaryIds(Long[] careerSalaryIds);

    /**
     * 删除职业薪资信息
     *
     * @param careerSalaryId 职业薪资主键
     * @return 结果
     */
    public int deleteMallCareerSalaryByCareerSalaryId(Long careerSalaryId);

    /**
     * 查询专业前景-职业薪资列表
     *
     * @param careerId 职业ID
     * @return 专业分类集合
     */
    public List<Map<String, Object>> selectMallCareerSalaryListByCareerId(Long careerId,String cityLevel);
}
